import setuptools
setuptools.setup(
 name='Topsis102003614',
 version='0.1',
 author="Ashutosh Bajpai",
 author_email="ashutoshbajpai171@gmail.com",
 description="CalcTopsis is a Python package implementing Topsis method sed for multi-criteria decision analysis. Topsis stands for Technique for Order of Preference by Similarity to Ideal Solution",
 packages=setuptools.find_packages(),
 classifiers=[
 "Programming Language :: Python :: 3",
 "License :: OSI Approved :: MIT License",
 "Operating System :: OS Independent",
 ],
)
